(function ($, Drupal) {
  let csrfToken;

  Drupal.behaviors.contentReporting = {
    attach: function (context, settings) {
      // Fetch the CSRF token
      fetch('/session/token')
        .then(response => response.text())
        .then(token => {
          csrfToken = token;

          // Check if nodeId is defined in drupalSettings
          if (typeof drupalSettings.nodeId !== 'undefined') {
            var uniqueToken = new Date().getTime();

            // Function to get cookie by name
            function getCookie(name) {
              let value = `; ${document.cookie}`;
              let parts = value.split(`; ${name} = `);
              if (parts.length === 2) {
                return parts.pop().split(';').shift();
              }
            }

            let gdprConsent;

            // Get GDPR consent from the cookie if available
            if (typeof Drupal.eu_cookie_compliance !== 'undefined') {
              gdprConsent = Drupal.eu_cookie_compliance.hasAgreed();
            }

            console.log('gdprConsent', gdprConsent);

            // Send a POST request to track content with nodeId and GDPR consent
            fetch('/track-content?' + uniqueToken, {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
                'X-CSRF-Token': token,
              },
              body: JSON.stringify({
                nid: drupalSettings.nodeId,
                gdpr_consent: gdprConsent,
              })
            })
              .then(response => {
                if (!response.ok) {
                  throw new Error('Network response was not ok');
                }
                return response.json();
              })
              .then(data => {
                console.log('Tracking success:', data);
              })
              .catch(error => {
                console.error('Tracking failed due to a network error:', error);
              });
          }
        })
        .catch(error => {
          console.error('Failed to fetch CSRF token:', error);
        });
    }
  };

  Drupal.behaviors.contentClickTracking = {
    attach: function (context, settings) {
      // Attach click event to links, buttons, and elements with class 'track-click'
      $('a, button, .track-click', context).on('click', function (event) {
        let elementId = $(this).attr('id') || $(this).text() || $(this).value || $(this).attr('aria-label');
        var nodeId = drupalSettings.nodeId;
        var uniqueToken = new Date().getTime();

        // Send a POST request to track click interactions
        $.ajax({
          url: '/track-content/interaction?' + uniqueToken,
          type: 'POST',
          data: JSON.stringify({
            nid: nodeId,
            interaction_type: 'click',
            element: elementId ? elementId : 'button'
          }),
          contentType: 'application/json',
          headers: {
            'X-CSRF-Token': csrfToken
          },
          success: function (response) {
            console.log('Click successfully tracked.');
          },
          error: function (error) {
            console.log('Error tracking the click:', error);
          }
        });
      });
    }
  };

  var timeSpent = 0;
  setInterval(function () {
    timeSpent += 10; // add 10 seconds
    // Send a POST request to track time spent on the content
    fetch('/track-content/interaction?' + new Date().getTime(), {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'X-CSRF-Token': csrfToken,
      },
      body: JSON.stringify({
        nid: drupalSettings.nodeId,
        interaction_type: 'time_spent',
        duration: timeSpent
      })
    });
  }, 10000); // every 10 seconds
})(jQuery, Drupal);
